===========================
mio |version| Documentation
===========================


:Release: |release|
:Date: |today|


About
=====

.. include:: ../../README.rst


.. _documentation-index:


Documentation
=============

.. toctree::
   :maxdepth: 2

   tutorial
   grammar
   api/index
   changes
   roadmap
   todo


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
